.. pg_grant documentation master file

pg_grant documentation
========================

``pg_grant`` is a Python module for parsing, querying, and updating PostgreSQL
privileges.

Contents:

.. toctree::
   :maxdepth: 3

   installation
   usage
   module

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
